@@ -2,27 +2,37 @@
 #'
 #' @description
 #'
-#' The function \code{contourPlot2} generates a contour plot of a given quantity,
+#' The function \code{contourPlot2} generates a contour plot of a scalar quantity,
 #' such as the ground concentration of an airborne pollutant or odour, defined on a
 #' regular grid.
 #'
 #' @param data A dataframe in long format with three columns for Easting,
 #' Northing and values to be plotted.
-#' @param x charactrer. Name of the column containing Easting (longitude)
+#' @param x character. Name of the column containing Easting (longitude)
 #' coordinates (default "x").
 #' @param y character. Name of the column containing Northing (latitude)
 #' coordinates (default "y").
 #' @param z character. Name of the column containing concentration values
 #' (default "z").
-#' @param domain optional list of six numeric values defining the
-#' boundaries of the domain to be plotted (minimum X, maximum X, minimum Y,
-#' maximum Y) and the number of ticks on X & Y axis.
-#' Example: c(340000, 346000, 4989500, 4995500, 5, 5).
-#' If missing, all the full domain of the input data is considered, with 5 ticks.
+#' @param domain optional list of six numeric values defining the boundaries of
+#' the domain to be plotted  and the number of ticks on X & Y axis
+#' (minimum X, maximum X, minimum Y, maximum Y, number of ticks on X axis,
+#' number of ticks on Y axis). Example: c(340000, 346000, 4989500, 4995500, 5, 5).
+#' If missing, the full domain of the input data is considered, with 5 ticks
+#' (deprecated, see `xlim`, `ylim`, `nticks`).
+#' @param xlim optional list of two numeric values defining the abscissa axis boundaries
+#' of the plot (minimum x, maximum x).
+#' @param ylim optional list of two numeric values defining the ordinate axis boundaries
+#' of the plot (minimum y, maximum y).
+#' @param nticks optional list of one or two numeric integers defining the number
+#' of ticks on X & Y axes. If a single number is given, the same number of ticks
+#' is plotted on both axes (default = 5 ticks).
 #' @param background filename. Optional path to a raster file to be plotted as
-#' the basemap.
-#' @param underlayer optional list of layers to be plotted between base map
-#' and contour plot. See Details
+#' the basemap (deprecated, see `basemap`)
+#' @param basemap filename. Optional path to a raster file to be plotted as
+#' the basemap (see Details).
+#' @param underlayer optional list of layers to be plotted between basemap
+#' and contour plot. See Details.
 #' @param overlayer optional list of layers to be plotted on top of the contour
 #' plot. See Details.
 #' @param legend character. Optional title of the legend.
@@ -31,15 +41,16 @@
 #' as the lowest and highest limits of the array, the lowest and highest bands
 #' are unbounded and the legend shows `<` and `>=` symbols.
 #' @param transparency transparency level of the contour plot between 0.0
-#' (fully transparent) and 1.0 (fully opaque). Default = 0.75).
+#' (fully transparent) and 1.0 (fully opaque). Default = 0.75.
 #' @param colors colour palette for contour plot, as an array of colours.
-#' @param bare boolean (default FALSE). If TRUE only the bare plot is shown:
+#' @param bare boolean (default FALSE). Deprecated in favour of `theme_void`.
+#' @param theme_void boolean (default FALSE). If TRUE, only the bare plot is shown:
 #' axis, legend, titles and any other graphical element of the plot are removed.
 #' @param size numeric. Width of the contour line.
-#' @param fill logical. If TRUE the contour plot is filled with colour (default = TRUE).
-#' @param tile logical. If TRUE rectangular tiles are plotted (default = FALSE).
-#' @param mask character. Path to _shp_ file used as a mask. It must be a closed polygon.
-#' @param inverse_mask logical. If `TRUE` areas on mask are masked. Default is
+#' @param fill logical. If TRUE, the contour plot is filled with colour (default = TRUE).
+#' @param tile logical. If TRUE, rectangular tiles are plotted (default = FALSE).
+#' @param mask character. Path to `shp` file used as a mask. It must be a closed polygon.
+#' @param inverse_mask logical. If TRUE, areas on mask are masked. Default is
 #' to mask areas outside the polygon defined in the _shp_ file.
 #'
 #' @details
@@ -49,15 +60,20 @@
 #' version >= 3.3.0.
 #'
 #' Data are required to be on a regular grid, typically (but not necessarily)
-#' in UTM coordinates. The input dataframe has to be in long format, i.e. one
-#' line per value to be plotted. The names of the columns corresponding to `x`,
-#' `y` and `z` can be specified in the input parameters.
+#' in UTM coordinates. Each value is associated to the cell centre.
+#' The input dataframe has to be in long format, i.e. one line per value to be plotted.
+#' The names of the columns corresponding to `x`, `y` and `z` can be specified in the
+#' input parameters.
+#'
+#' The `basemap` can be a geo-referenced TIFF file. In that case, the plot bounding box
+#' is automatically derived from the picture extent. The axis limits can be explicitly
+#' overridden by `xlim` and `ylim` arguments.
 #'
 #' If `tile = TRUE` data are shown as they are, without any graphical
 #' interpolation required for contour plots. This is helpful when you want to
 #' visualise the raw data.
 #' Since version 2.4.0, when `tile = TRUE` the intervals include the lowest
-#' bound and exclude the highest bound: `[min, max)`. Note: In previous version
+#' bound and exclude the highest bound: `[min, max)`. Note: In previous versions
 #' it was the opposite.
 #'
 #' `underlayer` and `overlayer` layers are \code{ggplot2} objects to be shown at
@@ -65,33 +81,35 @@
 #' show topographical information related to the plot, such as sources
 #' or receptors locations.
 #'
-#' When a _shp_ file is given to the `mask` argument the plot is drawn only
+#' When a _shp_ file is given to the `mask` argument, the plot is drawn only
 #' inside the polygon. In order to avoid boundary artifacts due to reduced
 #' resolution, original data are resampled to higher resolution (currently
-#' set to 10 times the original one.) If`inverse_mask` is set to `TRUE`, the plot
-#' is drawn outside  the polygon. The *mask* feature is based on the
+#' set to 10 times the original one). If `inverse_mask` is set to `TRUE`, the plot
+#' is drawn outside the polygon. The `mask` feature is based on the
 #' [terra::mask()] function.
 #' The CRS of the _shp_ file is applied to the data in the data.frame.
-#' Please, keep in mind this feature is still experimental.
+#' Please keep in mind this feature is still experimental.
 #'
 #' @return A \code{ggplot2} object.
 #'
 #' @importFrom grDevices colorRampPalette
-#' @importFrom ggplot2 ggplot annotation_custom geom_contour_filled
+#' @importFrom ggplot2 ggplot annotation_raster geom_contour_filled
 #'                     scale_fill_manual scale_x_continuous scale_y_continuous
 #'                     scale_color_manual coord_fixed theme_bw theme
 #'                     geom_blank guide_legend geom_raster after_stat
 #'                     geom_contour labs element_blank
 #' @importFrom grid rasterGrob
-#' @importFrom terra crs mask rast ext resample
+#' @importFrom terra crs mask rast as.raster ext resample xmin xmax ymin ymax
 #'
 #' @export
 #'
 #' @examples
 #' # Load example data in long format
 #' data(volcano)
-#' volcano3d <- reshape2::melt(volcano)
-#' names(volcano3d) <- c("x", "y", "z")
+#' volcano <- as.data.frame(volcano)
+#' volcano3d <- reshape(volcano, direction = "long",
+#'   varying = list(1:61),
+#'   idvar = "x", timevar = "y", v.names = "z")
 #' # Contour plot with default options
 #' v <- contourPlot2(volcano3d)
 #' v
@@ -123,7 +141,11 @@ contourPlot2 <- function(
     y = "y",
     z = "z",
     domain = NULL,
+    xlim = NULL,
+    ylim = NULL,
+    nticks = 5,
     background = NULL,
+    basemap = NULL,
     underlayer = NULL,
     overlayer = NULL,
     legend = NULL,
@@ -135,12 +157,13 @@ contourPlot2 <- function(
     colors = NULL,
     mask = NULL,
     inverse_mask = FALSE,
-    bare = FALSE
+    bare = FALSE,
+    theme_void = FALSE
 ) {
     # Consistency check
     if (isTRUE(tile)) {
         fill <- FALSE
-        bare <- FALSE
+        theme_void <- FALSE
         size <- 0.
     }
 
@@ -154,21 +177,78 @@ contourPlot2 <- function(
     }
     colnames(data) <- c("x", "y", "z")
 
-    # Define plot domain
-    if (missing(domain)) {
-        xmin <- min(data$x) # x coordinates minimum
-        xmax <- max(data$x) # x coordinates max
-        ymin <- min(data$y) # y coordinates min
-        ymax <- max(data$y) # y coordinates max
-        nx <- 5 # number of ticks along x axis
-        ny <- 5 # number of ticks along y axis
+    # Deprecate bare argument
+    if (isTRUE(bare)) {
+        theme_void <- bare
+        warning(paste(
+            "The \`bare\` argument is deprecated.",
+            "Please use argument \`theme_void\` instead."
+        ))
+    }
+
+    # Default limits for basemap
+    xmin_im <- -Inf
+    xmax_im <- Inf
+    ymin_im <- -Inf
+    ymax_im <- Inf
+
+    # Default limits for plot
+    xmin <- min(data$x)
+    xmax <- max(data$x)
+    ymin <- min(data$y)
+    ymax <- max(data$y)
+
+    # If we have a basemap, try to get boundaries from it
+    # Otherwise get them from data
+    if (!missing(basemap)) {
+        imgr <- tryCatch(
+            terra::rast(basemap),
+            warning = function(w) w
+        )
+        if (inherits(imgr, "SpatRaster")) {
+            # Bounding box for plot
+            xmin <- terra::xmin(imgr)
+            xmax <- terra::xmax(imgr)
+            ymin <- terra::ymin(imgr)
+            ymax <- terra::ymax(imgr)
+            # Bounding box for basemap (same)
+            xmin_im <- xmin
+            xmax_im <- xmax
+            ymin_im <- ymin
+            ymax_im <- ymax
+        }
+    }
+
+    # If required, override plot limits
+    if (!missing(domain)) {
+        warning(paste(
+            "The \`domain\` argument is deprecated.",
+            "Please use the \'xlim\', \'ylim\' and \'nticks\' arguments instead."
+        ))
+        xlim <- domain[1:2]
+        ylim <- domain[3:4]
+        nticks <- domain[5:6]
+    }
+
+    # Explicit boundaries
+    if (!missing(xlim)) {
+        xmin <- xlim[1] # x coordinates minimum
+        xmax <- xlim[2] # x coordinates max
+        if (xmax <= xmin) stop("Check xlim argument: max(x) <= min(x)")
+    }
+
+    if (!missing(ylim)) {
+        ymin <- ylim[1] # y coordinates min
+        ymax <- ylim[2] # y coordinates max
+        if (ymax <= ymin) stop("Check ylim argument: max(y) <= min(y)")
+    }
+
+    if (length(nticks) == 1) {
+        nx <- nticks # number of ticks along x axis
+        ny <- nticks # number of ticks along y axis
     } else {
-        xmin <- domain[1] # x coordinates minimum
-        xmax <- domain[2] # x coordinates max
-        ymin <- domain[3] # y coordinates min
-        ymax <- domain[4] # y coordinates max
-        nx <- domain[5] # number of ticks along x axis
-        ny <- domain[6] # number of ticks along y axis
+        nx <- nticks[1] # number of ticks along x axis
+        ny <- nticks[2] # number of ticks along y axis
     }
 
     # prettify legend title
@@ -276,16 +356,22 @@ contourPlot2 <- function(
         }
     }
 
-    # Background image
-    img <- matrix(data = NA, nrow = 10, ncol = 10)
-    gimg <- grid::rasterGrob(img, interpolate = FALSE)
+    # Basemap
     if (!missing(background)) {
+        warning(paste(
+            "The \`background\` argument is deprecated.",
+            "Please use the \'basemap\' argument instead."
+        ))
+        basemap <- background
+    }
+
+    if (!missing(basemap)) {
         if (requireNamespace("magick", quietly = TRUE)) {
-            img <- magick::image_read(background)
-            gimg <- grid::rasterGrob(img)
+            img <- magick::image_read(basemap)
+            gimg <- terra::as.raster(img)
         } else {
             warning(
-                "Missing magick package. Please install it to be able to read background basemap."
+                "Missing magick package. Please install it to read the basemap file."
             )
         }
     }
@@ -308,10 +394,14 @@ contourPlot2 <- function(
         size <- 0.
     }
 
-    # Base layer
-    v <- ggplot(data) +
-        annotation_custom(gimg, -Inf, Inf, -Inf, Inf) +
-        underlayer
+    # Basemap
+    v <- ggplot(data)
+    if (!missing(basemap)) {
+        v <- v + annotation_raster(gimg, xmin_im, xmax_im, ymin_im, ymax_im)
+    }
+
+    # Add underlayer
+    v <- v + underlayer
 
     # Tile plot
     if (isTRUE(tile)) {
@@ -415,7 +505,7 @@ contourPlot2 <- function(
         )
 
     # If requested, wipe all but main plot
-    if (isTRUE(bare)) {
+    if (isTRUE(theme_void)) {
         v <- v +
             theme(
                 axis.line = element_blank(),
