@@ -5,7 +5,7 @@
 #'
 #' @param mydata A dataframe containing data to plot.
 #' @param date The name of the column representing date and time. Data must be of
-#' class `POSIXlt` or `POSIXct` (default = "date"). If timezone is unspecified,
+#' class `POSIXlt` or `POSIXct` (default = "date"). If the timezone is unspecified,
 #' it is set to GMT.
 #' @param temp Name of the column representing temperature (default = "temp")
 #' @param avg.time Defines the time period to average to.
@@ -26,11 +26,12 @@
 #' @export
 #'
 #' @import grid
-#' @importFrom reshape2 melt
+#' @importFrom stats reshape
 #' @importFrom scales breaks_width label_date label_math
 #' @importFrom ggplot2 ggplot geom_col geom_line labs scale_x_continuous
 #'                     expansion margin element_blank geom_text
-#'                     scale_y_discrete
+#'                     scale_y_discrete scale_color_manual scale_fill_manual
+#'                     theme unit
 #'
 #' @examples
 #' # Plot average monthly temperature and curves with monthly maximum and minimum
@@ -65,12 +66,12 @@ plotAvgTemp <- function(
         stop("A `date` column of class <POSIXt> is required.")
     }
 
-    # Special case for italian locale
+    # Special case for Italian locale
     if (!is.null(locale) && locale == "it") {
         locale <- "it_IT"
     }
 
-    # Get locale if not explicitely set
+    # Get locale if not explicitly set
     if (is.null(locale)) {
         locale <- Sys.getlocale(category = "LC_TIME")
     }
@@ -84,7 +85,7 @@ plotAvgTemp <- function(
         }
     }
     # If the user explicitely set ylabel = NULL set it to an empty string.
-    # This is for adding an extra space on the right and imporve alignment
+    # This is for adding an extra space on the right and improve alignment
     # with the table below.
     if (is.null(ylabel)) {
         ylabel <- ""
@@ -131,13 +132,17 @@ plotAvgTemp <- function(
 
     # Set column names and create a row index column
     colnames(mydata_mean) <- c("rid", "temp", "temp.min", "temp.max")
-    # FIXME:make it more generic
+    # FIXME: make it more generic
     mydata_mean[["rid"]] <- as.numeric(mydata_mean[["rid"]])
 
     # Arrange data in long format
-    mydata <- reshape2::melt(
+    mydata <- stats::reshape(
         mydata_mean,
-        measure.vars = c("temp.min", "temp", "temp.max")
+        direction = "long",
+        varying = list(2:4),
+        times = c("temp", "temp.min", "temp.max"),
+        timevar = "variable",
+        v.names = "value"
     )
     mydata$value <- round(mydata$value, digits = 1)
 
@@ -244,7 +249,6 @@ plotAvgTemp <- function(
             expand = expansion(add = c(0.47, 0.5), mult = 0.02),
         ) +
         scale_y_discrete(labels = c(minima_short, media_short, massima_short)) +
-        theme_bw() +
         labs(title = NULL, x = NULL, y = "") +
         theme_bw(base_family = "sans") +
         theme(
@@ -277,10 +281,10 @@ plotAvgTemp <- function(
         grid::grid.newpage()
         grid::pushViewport(grid::viewport(layout = mylayout))
         grid::pushViewport(viewport(layout.pos.col = 1, layout.pos.row = 1))
-        grid.draw(a)
+        grid::grid.draw(a)
         grid::upViewport()
         grid::pushViewport(viewport(layout.pos.col = 1, layout.pos.row = 2))
-        grid.draw(b)
+        grid::grid.draw(b)
     }
     gg_vertical_draw(g1, g2)
 }
