@@ -26,14 +26,17 @@
 #'
 #' @importFrom scales label_percent
 #' @importFrom ggplot2 ggplot geom_bar labs element_blank guides
+#'                     theme_bw theme scale_fill_manual scale_x_continuous
+#'                     scale_y_continuous
+#' @importFrom lubridate month
 #'
 #' @examples
 #' data("stMeteo")
 #'
-#' # Season plot of stability class pgt
+#' # Season plot of PGT stability class
 #' plotStabilityClass(stMeteo, date = "date", sc = "pgt", type = "season")
 #'
-#' # Hourly plot of stability class pgt
+#' # Hourly plot of PGT stability class
 #' plotStabilityClass(stMeteo, date = "date", sc = "pgt", type = "hour")
 #'
 #' # Override default locale
@@ -84,7 +87,7 @@ plotStabilityClass <- function(
     }
 
     pasquill <- factor(x = c("A", "B", "C", "D", "E", "F"))
-    mydata$clname <- pasquill[mydata[, sc]]
+    mydata$clname <- pasquill[mydata[[sc]]]
     mydata$clname <- factor(mydata$clname, levels = sort(pasquill, decreasing = TRUE))
 
     if (grepl("it", locale)) {
